<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Payment;
use DataTables;
use Illuminate\Http\Request;
use App\Models\UserWallet;
use Config;

class PaymentController extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = Payment::select('*')->orderBy('created_at', 'DESC');

            return DataTables::of($data)
                    ->addIndexColumn()
                    ->addColumn('fullname', function ($row) {
                        $val = $row->user->name;
                        $btn = $val;

                        return $btn;
                    })
                    ->addColumn('mobile', function ($row) {
                        $val = $row->user->mobile;
                        $btn = $val;

                        return $btn;
                    })
                    ->addColumn('register_date', function ($row) {
                        $val = date('Y-m-d h:i A', strtotime($row->register_date));
                        $btn = '<div class="row">'.$val.'</div>';

                        return $btn;
                    })
                    ->addColumn('first_payment_date', function ($row) {
                        $val = $row->first_payment_date;
                        $btn = '<div class="row">'.$val.'</div>';

                        return $btn;
                    })
                    ->addColumn('second_payment_date', function ($row) {
                        $val = $row->second_payment_date;
                        $btn = '<div class="row">'.$val.'</div>';

                        return $btn;
                    })
                    ->addColumn('payment_type', function ($row) {
                        $val = $row->payment_type;
                        if($val == '1'){
                            $data = 'Wallet';
                        } else {
                            $data = 'QR-Code';
                        }
                        $btn = '<div class="row">'.$data.'</div>';

                        return $btn;
                    })
                    ->addColumn('status', function ($row) {
                        $btn = '<div class="row btn-status-div-'.$row->id.'">';
                        if ($row->status == 0) {
                            $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" column="status" value="1" class="btn btn-primary btn-sm ml-2 btn-status">Approve</a>';
                            $btn .= '&nbsp;&nbsp;';
                            $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" column="status" value="2" class="btn btn-primary btn-sm ml-2 btn-status">Reject</a>';
                        } elseif ($row->status == 1) {
                            $btn .= '<a href="javascript:void(0)" class="btn btn-success btn-sm ml-2">Approved</a>';
                        } elseif ($row->status == 2) {
                            $btn .= '<a href="javascript:void(0)" class="btn btn-danger  btn-sm ml-2">Rejected</a>';
                        }
                        $btn .= '</div>';

                        return $btn;
                    })
                    ->addColumn('payment', function ($row) {
                        $btn = '<div class="row btn-payment-div-'.$row->id.'">';
                        if ($row->status == 1) {
                            $date = date('Y-m-d');
                            if ($row->first_payment_status == 1 && $row->second_payment_status == 1) {
                                $btn .= '<a href="javascript:void(0)" class="btn btn-success btn-sm ml-2">Payment Done</a>';
                            } elseif ($row->first_payment_status == 0) {
                                $firstPayment = ($row->first_payment_date > $date) ? 'disabled' : '';
                                $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" column="first_payment_status" value="1" class="btn btn-primary btn-sm ml-2 btn-status '.$firstPayment.'">Pay First EMI</a>';
                            } else {
                                $secondPayment = ($row->second_payment_date > $date) ? 'disabled' : '';
                                $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" column="second_payment_status" value="1" class="btn btn-primary btn-sm ml-2 btn-status '.$secondPayment.'">Pay Second EMI</a>';
                            }
                        } else {
                            $btn .= '--Not Available--';
                        }
                        $btn .= '</div>';

                        return $btn;
                    })
                    ->addColumn('action', function ($row) {
                        $btn = '<div class="row"><a href="javascript:void(0)" id="'.$row->id.'" class="btn btn-primary btn-sm ml-2 btn-view" title="View Details"><i class="fas fa-info-circle"></i></a>';

                        return $btn;
                    })
                    ->rawColumns(['action', 'status', 'payment_type','register_date', 'payment', 'first_payment_date', 'second_payment_date'])
                    ->make(true);
        }

        return view('admin.payment.index');
    }

    public function updatePaymentStatus($id, $column, $value)
    {
        $res = [
            'msg' => 'Not update please try again.',
            'status' => 0,
        ];
        $paymentData = Payment::find($id);
        $paymentData->$column = $value;
        if ($paymentData->save()) {

            if( $column == 'status' ){

                if($value == 1){
                    UserWallet::where(['referral_user_id'=> $paymentData->user_id,'is_updated'=>0])
                    ->update(['status' => 1,'is_updated'=>1]);

                    if($paymentData->payment_type == 1){
                        $update = ['payment_type'=>Config::get('constants.USER_WALLET_STATUS.APPROVED_PURCHASE_TICKET_BY_WALLET')];
                    } else {
                        $update = ['payment_type'=>Config::get('constants.USER_WALLET_STATUS.APPROVED_PURCHASE_TICKET')];
                    }
                    
                } else if($value == 2){
                    UserWallet::where(['referral_user_id'=> $paymentData->user_id, 'is_updated'=> 0])
                    ->update(['status' => 2,'is_updated'=>1]);

                    if($paymentData->payment_type == 1){
                        $update = ['payment_type'=>Config::get('constants.USER_WALLET_STATUS.REJECT_PURCHASE_TICKET_BY_WALLET')];
                    } else {
                        $update = ['payment_type'=>Config::get('constants.USER_WALLET_STATUS.REJECT_PURCHASE_TICKET')];
                    }
                    
                }
                UserWallet::where('payment_id', $paymentData->id)
                    ->update($update);
            }

            if($column == 'first_payment_status'){
                $dateTime = date('Y-m-d H:i:s');
                $wallet = new UserWallet;
                $wallet->user_id = $paymentData->user_id;
                $wallet->payment_id = $paymentData->id;
                $wallet->amount =  Config::get('constants.FIRST_EMI_PAYMENT');
                $wallet->date =  $dateTime;
                $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.FIRST_EMI_APPROVED');
                $wallet->save();
            }

            if($column == 'second_payment_status'){
                $dateTime = date('Y-m-d H:i:s');
                $wallet = new UserWallet;
                $wallet->user_id = $paymentData->user_id;
                $wallet->payment_id = $paymentData->id;
                $wallet->amount =  Config::get('constants.SECOND_EMI_PAYMENT');
                $wallet->date =  $dateTime;
                $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.SECOND_EMI_APPROVED');
                $wallet->save();
            }

            $res['msg'] = 'Ticket ID '.$paymentData->ticket_id.' updated successfully.';
            $res['status'] = 1;
        }

        return response()->json($res);
    }

    public function show($id)
    {
        $paymentData = Payment::with('user')->find($id);

        return response()->json($paymentData);
    }

    public function sponsorDetail(Request $request)
    {
        if ($request->query('date')) {
            $date = $request->query('date');
        } else {
            $date = date('Y-m-d');
        }

        $sponsorsArr = [];
        $paymentData = Payment::select(['sponsor_name', 'sponsor_id', 'register_date'])
        ->whereDate('register_date', '=', $date)
        ->get();
        foreach ($paymentData as $k => $data) {
            $id = trim(strtolower($data->sponsor_name).'_'.$data->sponsor_id);
            if (array_key_exists($id, $sponsorsArr)) {
                $sponsorsArr[$id] = $sponsorsArr[$id] + 1;
            } else {
                $sponsorsArr[$id] = 1;
            }
        }

        return view('admin.payment.sponsor', compact('sponsorsArr', 'date'));
    }

    public function emiDetail(Request $request)
    {

        $responseArr = [];
        $date=date_create("2021-08-25");
        $paymentData = Payment::get()->groupBy('mobile');
        //dd($paymentData);
        foreach ($paymentData as $kNumber => $numberData) {
            $firstEMIPay = 0;
            $fullname = '';
            $secondEMIPay = 0;
            $responseArr[$kNumber]['total_payment'] = count($numberData);
            $totalSponserCount = Payment::where(['sponsor_id'=>$kNumber])->whereDate('register_date' ,'<',$date)->count();
            foreach($numberData as $k => $data){
                $fullname = $data->fullname;
                if($data->first_payment_status == 1){
                    $firstEMIPay = $firstEMIPay +1;
                }
                if($data->second_payment_status == 1){
                    $secondEMIPay = $secondEMIPay +1;
                }
            }
            $responseArr[$kNumber]['fullname'] = $fullname;
            $responseArr[$kNumber]['total_first_emi_pay'] = $firstEMIPay;
            $responseArr[$kNumber]['total_second_emi_pay'] = $secondEMIPay;
            $responseArr[$kNumber]['total_sponsor_count'] = $totalSponserCount;

        }
        //dd($responseArr);

        return view('admin.payment.emi', compact('responseArr', 'date'));
    }


    public function emiDetail2(Request $request)
    {

        $responseArr = [];
        $date=date_create("2021-08-25");
        $paymentData = Payment::get()->groupBy('mobile');
        //dd($paymentData);
        foreach ($paymentData as $kNumber => $numberData) {
            $firstEMIPay = 0;
            $fullname = '';
            $secondEMIPay = 0;
            $responseArr[$kNumber]['total_payment'] = count($numberData);
            $totalSponserCount = Payment::where(['sponsor_id'=>$kNumber])->whereDate('register_date' ,'<',$date)->count();
            foreach($numberData as $k => $data){
                $fullname = $data->fullname;
                if($data->first_payment_status == 1){
                    $firstEMIPay = $firstEMIPay +1;
                }
                if($data->second_payment_status == 1){
                    $secondEMIPay = $secondEMIPay +1;
                }
            }
            $responseArr[$kNumber]['fullname'] = $fullname;
            $responseArr[$kNumber]['total_first_emi_pay'] = $firstEMIPay;
            $responseArr[$kNumber]['total_second_emi_pay'] = $secondEMIPay;
            $responseArr[$kNumber]['total_sponsor_count'] = $totalSponserCount;

        }

        return view('admin.payment.emi2', compact('responseArr', 'date'));
    }
}
