<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\UserWallet;
use DataTables;
use Hash;
use Illuminate\Http\Request;
use Config;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Request as Req;
use App\Helper\CommonHelper;

class UserController extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = User::select('*')->where('role','user')->orderBy('created_at', 'DESC');

            return DataTables::of($data)
                    ->addIndexColumn()
                    ->addColumn('status', function ($row) {
                        $val = $row->status;
                        if($val == 0){
                            return 'Inactive';
                        } else {
                            return 'Active';
                        }
                    })
                    ->addColumn('available_balance', function ($row) {
                        return CommonHelper::getUserWalletAmount($row->id);
                        
                    })
                    ->addColumn('created_at', function ($row) {
                        $val = date('Y-m-d h:i A', strtotime($row->created_at));
                        $btn = '<div class="row">'.$val.'</div>';
                        return $btn;
                    })
                    ->addColumn('action', function ($row) {
                        $btn = '<div class="row"><a href="javascript:void(0)" id="'.$row->id.'" class="btn btn-primary btn-sm ml-2 btn-edit">Edit</a>';
                        $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" class="btn btn-warning btn-sm ml-2 btn-view">View</a>';
                        $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" class="btn btn-danger btn-sm ml-2 btn-delete">Delete</a>';
                        // $btn .= '<a href="'.route('user-wallet',['userid'=>$row->id]).'" class="btn btn-warning btn-sm ml-2 btn-wallet">Wallet</a></div>';

                        return $btn;
                    })
                    ->rawColumns(['action','created_at'])
                    ->make(true);
        }

        return view('admin.user.index');
    }

    public function wallet(Request $request,$userId = null){
        if ($request->ajax()) {
            $userId = (Req::input('userid')) ? Req::input('userid') : null;
            if($userId){
                $data = UserWallet::select('*')->where('user_id',$userId)->with(['user','payment'])->orderBy('created_at', 'DESC');
            } else {
                $data = UserWallet::select('*')
                ->whereIn('payment_type',[Config::get('constants.USER_WALLET_STATUS.WITHDRAW_REQUEST'),Config::get('constants.USER_WALLET_STATUS.APPROVED_WITHDROW_REQUEST'),Config::get('constants.USER_WALLET_STATUS.REJECT_WITHDROW_REQUEST')])
                ->with(['user','payment'])
                ->orderBy('created_at', 'DESC');
            }
            

            return DataTables::of($data)
                    ->addIndexColumn()
                    ->addColumn('payment_type', function ($row) {
                        $val = $row->payment_type;
                        $status = $row->status;
                        $badgeCls = 'badge-secondary';
                        $msg = '';
                        if($val == Config::get('constants.USER_WALLET_STATUS.PURCHASE_TICKET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.PURCHASE_TICKET');
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.WITHDRAW_REQUEST')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.WITHDRAW_REQUEST');
                            $badgeCls = 'badge-warning';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.APPROVED_WITHDROW_REQUEST')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_WITHDROW_REQUEST');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REJECT_WITHDROW_REQUEST')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_WITHDROW_REQUEST');
                            $badgeCls = 'badge-danger';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REFERRAL_REWARD') && $status == '2'){
                            //$msg = Config::get('constants.USER_WALLET_STATUS_MSG.REFERRAL_REWARD');
                            $msg = 'Earn by Referral (waiting for user ticket purchase)';
                            $badgeCls = 'badge-warning';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REFERRAL_REWARD') && $status == '1'){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REFERRAL_REWARD');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.FIRST_EMI_APPROVED')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.FIRST_EMI_APPROVED');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.SECOND_EMI_APPROVED')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.SECOND_EMI_APPROVED');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.PURCHASE_TICKET_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.PURCHASE_TICKET_WALLET');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.APPROVED_PURCHASE_TICKET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_PURCHASE_TICKET');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REJECT_PURCHASE_TICKET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_PURCHASE_TICKET');
                            $badgeCls = 'badge-danger';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.APPROVED_PURCHASE_TICKET_BY_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_PURCHASE_TICKET_BY_WALLET');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REJECT_PURCHASE_TICKET_BY_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_PURCHASE_TICKET_BY_WALLET');
                            $badgeCls = 'badge-danger';
                        }
                        $btn = '<div id="payment-type-'.$row->id.'"><span class="badge '.$badgeCls.'">'.$msg.'</span>';
                        if($row->payment_type == Config::get('constants.USER_WALLET_STATUS.WITHDRAW_REQUEST')){
                            $btn .= '<br/><a href="javascript:void(0)" id="'.$row->id.'" column="payment_type" value="'.Config::get('constants.USER_WALLET_STATUS.APPROVED_WITHDROW_REQUEST').'" class="btn btn-primary btn-sm ml-2 btn-payment-type">Approve</a>';
                            $btn .= '&nbsp;&nbsp;';
                            $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" column="payment_type" value="'.Config::get('constants.USER_WALLET_STATUS.REJECT_WITHDROW_REQUEST').'" class="btn btn-primary btn-sm ml-2 btn-payment-type">Reject</a>';
                        }
                        $btn .= '</div>';
                        return $btn;
                    })
                    ->addColumn('amount', function ($row) {
                        $btn = '<div class="row">'.$row->amount.'</div>';
                        return $btn;
                    })
                    ->addColumn('date', function ($row) {
                        $val = date('Y-m-d h:i A', strtotime($row->date));
                        $btn = '<div class="row">'.$val.'</div>';
                        return $btn;
                    })
                    ->addColumn('user_detail', function ($row) {
                        $value = $row->user->name;
                        if(isset($row->payment->ticket_id)){
                            $value .= '<br>'.$row->payment->ticket_id;
                        }
                        $btn = '<div class="row">'.$value.'</div>';
                        return $btn;
                    })
                    ->addColumn('action', function ($row) {
                        $btn = '<div class="row">';
                        
                        $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" class="btn btn-warning btn-sm ml-2 btn-view">View</a></div>';
                       
                        return $btn;
                    })
                    ->rawColumns(['action','payment_type','date','user_detail','amount'])
                    ->make(true);
        }
        return view('admin.user.wallet',compact('userId'));
    }

    public function updateWalletStatus($id, $column, $value, $walletAmount = null)
    {
        $res = [
            'msg' => 'Not update please try again.',
            'status' => 0,
        ];
        $paymentData = UserWallet::find($id);
        $paymentData->$column = $value;
        if($walletAmount){
            $paymentData->amount = trim($walletAmount); 
        }
        if ($paymentData->save()) {
            if($value == Config::get('constants.USER_WALLET_STATUS.APPROVED_WITHDROW_REQUEST')){
                $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_WITHDROW_REQUEST');
            } else if($value == Config::get('constants.USER_WALLET_STATUS.REJECT_WITHDROW_REQUEST')){
                $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_WITHDROW_REQUEST');
            } else if($value == Config::get('constants.USER_WALLET_STATUS.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET')){
                $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET');
            } else if($value == Config::get('constants.USER_WALLET_STATUS.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET')){
                $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET');
            }
            $name = ($value == 1) ? 'approved' : 'rejected';
            $res['msg'] = 'Request '.$name.' successfully.';
            $res['payment_type'] = 1;
            $res['status_label'] = '<span class="badge badge-secondary">'.$msg.'</span>';
        }
        

        return response()->json($res);
    }


    
    public function walletDetail($id)
    {
        
        $data = UserWallet::with(['user','payment'])->find($id);
        $paymentStatus = '';
        if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.PURCHASE_TICKET')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.PURCHASE_TICKET');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.WITHDRAW_REQUEST')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.WITHDRAW_REQUEST');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.APPROVED_WITHDROW_REQUEST')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_WITHDROW_REQUEST');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.REJECT_WITHDROW_REQUEST')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_WITHDROW_REQUEST');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.REFERRAL_REWARD')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.REFERRAL_REWARD');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.FIRST_EMI_APPROVED')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.FIRST_EMI_APPROVED');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.SECOND_EMI_APPROVED')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.SECOND_EMI_APPROVED');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.PURCHASE_TICKET_WALLET')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.PURCHASE_TICKET_WALLET');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.PENDING_AMOUNT_ADD_REQUEST_IN_WALLET')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.PENDING_AMOUNT_ADD_REQUEST_IN_WALLET');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET');
        } else if($data->payment_type == Config::get('constants.USER_WALLET_STATUS.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET')){
            $paymentStatus = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET');
        }
        $data['payment_type_name'] = $paymentStatus;
        $res['msg'] = 'Record Found';
        $res['status'] = 1;
        $res['data'] = $data;
        return response()->json($res);
    }

    public function create()
    {
    }

    public function store(Request $request)
    {
        $request->request->add(['password' => Hash::make($request->password)]);
        User::create($request->all());
    }

    public function show($id)
    {
    }

    public function edit($id)
    {
       
        $userData = User::with('parentUser')->find($id);
        //dd($userData);
        $userData['available_balance'] = CommonHelper::getUserWalletAmount($id);
        
        return response()->json($userData);
    }

    public function update(Request $request, User $user)
    {
        $user->update($request->all());
    }

    public function destroy(User $user)
    {
        $user->delete();
    }


    public function addMoneyInWallet(Request $request,$userId = null){
        if ($request->ajax()) {
            $userId = (Req::input('userid')) ? Req::input('userid') : null;
            $data = UserWallet::select('*')
                ->whereIn('payment_type',[Config::get('constants.USER_WALLET_STATUS.PENDING_AMOUNT_ADD_REQUEST_IN_WALLET'),Config::get('constants.USER_WALLET_STATUS.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET'),Config::get('constants.USER_WALLET_STATUS.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET')])
                ->with(['user','payment'])
                ->orderBy('created_at', 'DESC');
            

            return DataTables::of($data)
                    ->addIndexColumn()
                    ->addColumn('payment_type', function ($row) {
                        $val = $row->payment_type;
                        $status = $row->status;
                        $badgeCls = 'badge-secondary';
                        $msg = '';
                        if($val == Config::get('constants.USER_WALLET_STATUS.PURCHASE_TICKET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.PURCHASE_TICKET');
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.WITHDRAW_REQUEST')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.WITHDRAW_REQUEST');
                            $badgeCls = 'badge-warning';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.APPROVED_WITHDROW_REQUEST')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_WITHDROW_REQUEST');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REJECT_WITHDROW_REQUEST')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_WITHDROW_REQUEST');
                            $badgeCls = 'badge-danger';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REFERRAL_REWARD') && $status == '2'){
                            //$msg = Config::get('constants.USER_WALLET_STATUS_MSG.REFERRAL_REWARD');
                            $msg = 'Earn by Referral (waiting for user ticket purchase)';
                            $badgeCls = 'badge-warning';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REFERRAL_REWARD') && $status == '1'){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REFERRAL_REWARD');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.FIRST_EMI_APPROVED')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.FIRST_EMI_APPROVED');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.SECOND_EMI_APPROVED')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.SECOND_EMI_APPROVED');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.PURCHASE_TICKET_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.PURCHASE_TICKET_WALLET');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.APPROVED_PURCHASE_TICKET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_PURCHASE_TICKET');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REJECT_PURCHASE_TICKET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_PURCHASE_TICKET');
                            $badgeCls = 'badge-danger';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.APPROVED_PURCHASE_TICKET_BY_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_PURCHASE_TICKET_BY_WALLET');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REJECT_PURCHASE_TICKET_BY_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_PURCHASE_TICKET_BY_WALLET');
                            $badgeCls = 'badge-danger';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.PENDING_AMOUNT_ADD_REQUEST_IN_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.PENDING_AMOUNT_ADD_REQUEST_IN_WALLET');
                            $badgeCls = 'badge-warning';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET');
                            $badgeCls = 'badge-success';
                        } else if($val == Config::get('constants.USER_WALLET_STATUS.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET')){
                            $msg = Config::get('constants.USER_WALLET_STATUS_MSG.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET');
                            $badgeCls = 'badge-danger';
                        }
                        $btn = '<div id="payment-type-'.$row->id.'"><span class="badge '.$badgeCls.'">'.$msg.'</span>';
                        if($row->payment_type == Config::get('constants.USER_WALLET_STATUS.PENDING_AMOUNT_ADD_REQUEST_IN_WALLET')){
                            $btn .= '<br/><a href="javascript:void(0)" id="'.$row->id.'" amount="'.$row->amount.'" column="payment_type" value="'.Config::get('constants.USER_WALLET_STATUS.APPROVED_AMOUNT_ADD_REQUEST_IN_WALLET').'" class="btn btn-primary btn-sm ml-2 btn-payment-add-wallet">Approve</a>';
                            $btn .= '&nbsp;&nbsp;';
                            $btn .= '<a href="javascript:void(0)" id="'.$row->id.'"  amount="'.$row->amount.'" column="payment_type" value="'.Config::get('constants.USER_WALLET_STATUS.REJECT_AMOUNT_ADD_REQUEST_IN_WALLET').'" class="btn btn-primary btn-sm ml-2 btn-payment-type">Reject</a>';
                        }
                        $btn .= '</div>';
                        return $btn;
                    })
                    ->addColumn('amount', function ($row) {
                        $btn = '<div class="row " id="amount-'.$row->id.'">'.$row->amount.'</div>';
                        return $btn;
                    })
                    ->addColumn('date', function ($row) {
                        $val = date('Y-m-d h:i A', strtotime($row->date));
                        $btn = '<div class="row">'.$val.'</div>';
                        return $btn;
                    })
                    ->addColumn('user_detail', function ($row) {
                        $value = $row->user->name;
                        if(isset($row->payment->ticket_id)){
                            $value .= '<br>'.$row->payment->ticket_id;
                        }
                        $btn = '<div class="row">'.$value.'</div>';
                        return $btn;
                    })
                    ->addColumn('action', function ($row) {
                        $btn = '<div class="row">';
                        
                        $btn .= '<a href="javascript:void(0)" id="'.$row->id.'" class="btn btn-warning btn-sm ml-2 btn-view">View</a></div>';
                       
                        return $btn;
                    })
                    ->rawColumns(['action','payment_type','date','user_detail','amount'])
                    ->make(true);
        }
        return view('admin.user.add_money',compact('userId'));
    }
}
