<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Models\Payment;
use App\Models\Setting;
use App\Models\TempUser;
use App\Models\User;
use Auth;
use Config;
use Cookie;
use DB;
use Hash;
use Illuminate\Http\Request;
use Image;
use Session;
use Validator;
use App\Models\UserWallet;
use App\Helper\CommonHelper;

class UserController extends Controller
{
    public function index()
    {
        return view('user.index');
    }

    public function purchaseTicket(Request $request)
    {
        $isDisablePurcahseButton = false;
        $invlaidBankDetail = false;
        if (date('H:i:s') < '08:00:00') {
            $isDisablePurcahseButton = true;
        }
        $userData = Auth::user();
        $userId = $userData->id;
        if($userId == 36){
            $invlaidBankDetail = true;
        }
        $walletAmount = CommonHelper::getUserWalletAmount($userId);
        $purchaseAmount = Config::get('constants.TICKET_PURCHASE_WALLET_AMOUNT');

        $isTicketAvailable = self::getAvailableTicket();
        $isPurchased = false;
        if ($request->cookie('uniqueId')) {
            $uniqueId = $request->cookie('uniqueId');
            $userData = DB::table('temp_user')->where('unique_id', $uniqueId)->get();
            if (count($userData) > 0) {
                $isPurchased = true;
            }
        }

        return view('user.purchase_ticket', compact('invlaidBankDetail','isPurchased', 'isTicketAvailable', 'isDisablePurcahseButton','walletAmount','purchaseAmount'));
    }

    public function purchasePin()
    {
        $uniqueId = rand(10, 100) . date('dhis');
        $minutes = Config::get('constants.COOKIE_TIME');
        Cookie::queue('uniqueId', $uniqueId, $minutes);
        $dateTime = date('Y-m-d H:i:s');
        $data = ['unique_id' => $uniqueId, 'purchase_date' => $dateTime];
        DB::table('temp_user')->insert($data);
        $isPurchased = true;

        return redirect('purchase-ticket');
    }

    public static function getAvailableTicket()
    {
        $settingData = Setting::select('value_data')->where('value_label', 'TICKET_LIMIT')->first();
        $ticketLimit = $settingData->value_data;
        $today = date('Y-m-d');
        $tempTodayPurchaseCount = TempUser::whereDate('purchase_date', '=', $today)->count();
        $purchaseCount = Payment::where('status', '!=', '2')->whereDate('register_date', '=', $today)->count();
        $totalCount = $purchaseCount + $tempTodayPurchaseCount;
        if ($ticketLimit > $totalCount) {
            return true;
        } else {
            return false;
        }
    }

    public function purchaseTicketForm(Request $request)
    {
        $ticketAmount = Config::get('constants.TICKET_PURCHASE_AMOUNT');
        $isPurchased = false;
        if ($request->cookie('uniqueId')) {
            $uniqueId = $request->cookie('uniqueId');
            $userData = DB::table('temp_user')->where('unique_id', $uniqueId)->get();
            if (count($userData) > 0) {
                $isPurchased = true;
            }
        }

        if ($isPurchased) {
            $input = $request->all();
            $ticketId = 'TC' . rand(10, 100) . date('ymdhis');
            $registerDate = date('Y-m-d H:i:s');
            $firstPaymentTime = Config::get('constants.FIRST_PAYMENT_TIME');
            $secondPaymentTime = Config::get('constants.SECOND_PAYMENT_TIME');

            if ($request->hasFile('payment_schreenshot')) {
                $extension = $input['payment_schreenshot']->getClientOriginalExtension();
                $fileName = time() . '-payment-image.' . $extension;

                if ($input['payment_schreenshot']->move('public/uploads/payment/', $fileName)) {
                    // $img = Image::make('uploads/payment/'.$fileName);
                    // $img->resize(500, 500);
                    // $img->save('uploads/payment/'.$fileName);
                    $input['payment_image'] = $fileName;
                }
            }
            $userData = Auth::user();
            $payment = Payment::create([
                'ticket_id' => $ticketId,
                'user_id'=> $userData->id,
                'amount'=> $ticketAmount,
                'payment_image' => $input['payment_image'],
                'register_date' => $registerDate,
                'first_payment_date' => date('Y-m-d', strtotime('+' . $firstPaymentTime . ' days')),
                'second_payment_date' => date('Y-m-d', strtotime('+' . $secondPaymentTime . ' days')),
            ]);
            if ($payment) {
                $dateTime = date('Y-m-d H:i:s');
                $wallet = new UserWallet;
                $wallet->user_id = $userData->id;
                $wallet->payment_id = $payment->id;
                $wallet->amount =  $ticketAmount;
                $wallet->date =  $dateTime;
                $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.PURCHASE_TICKET');
                $wallet->save();

                $ticketId = $payment->ticket_id;
                $uniqueId = $request->cookie('uniqueId');
                DB::delete('delete from temp_user where unique_id = ?', [$uniqueId]);
                Cookie::queue(Cookie::forget('uniqueId'));

                return redirect()->route('thank-you', ['pId' => $ticketId]);
            } else {
                Cookie::queue(Cookie::forget('uniqueId'));
                echo '<h1 style="font-size: 99px;">something went wrong, please contact to admin for more info</h1>';
                exit;
            }
        } else {
            Cookie::queue(Cookie::forget('uniqueId'));
            echo '<h1 style="font-size: 99px;">Sorry for that but currently tickets are not available please contact to admin for more info.</h1>';
            exit;
        }
    }

    public function purchasePinByWallet(){

        $userData = Auth::user();
        $ticketAmount = Config::get('constants.TICKET_PURCHASE_AMOUNT');
        $ticketId = 'TC' . rand(10, 100) . date('ymdhis');
        $registerDate = date('Y-m-d H:i:s');
        $firstPaymentTime = Config::get('constants.FIRST_PAYMENT_TIME');
        $secondPaymentTime = Config::get('constants.SECOND_PAYMENT_TIME');

        $payment = Payment::create([
            'ticket_id' => $ticketId,
            'user_id'=> $userData->id,
            'amount'=> $ticketAmount,
            'register_date' => $registerDate,
            'payment_type'=>'1',
            'status'=>'1',
            'first_payment_date' => date('Y-m-d', strtotime('+' . $firstPaymentTime . ' days')),
            'second_payment_date' => date('Y-m-d', strtotime('+' . $secondPaymentTime . ' days')),
        ]);
        if ($payment) {
            $dateTime = date('Y-m-d H:i:s');
            $wallet = new UserWallet;
            $wallet->user_id = $userData->id;
            $wallet->payment_id = $payment->id;
            $wallet->amount =  $ticketAmount;
            $wallet->date =  $dateTime;
            $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.APPROVED_PURCHASE_TICKET_BY_WALLET');
            $wallet->save();

            $ticketId = $payment->ticket_id;

            UserWallet::where(['referral_user_id'=> $userData->id,'is_updated'=>0])
            ->update(['status' => 1,'is_updated'=>1]);

            return response()->json(['status' => true, 'msg' =>  'Thank you for purchase ticket, your ticket ID is : '.$ticketId]);
            //return redirect()->route('thank-you', ['pId' => $ticketId]);
        } else {
            return response()->json(['status' => false, 'msg' =>  'something went wrong, please contact to admin for more info']);
           // echo '<h1 style="font-size: 99px;">something went wrong, please contact to admin for more info</h1>';
            //exit;
        }
    }

    public function thankYou($pId)
    {
        return view('user.thankyou', compact('pId'));
    }

    public function resetPayments()
    {
        DB::delete('DELETE FROM temp_user WHERE purchase_date < (NOW() - INTERVAL 9 MINUTE)');
        exit('success');
    }

    public function register()
    {
        return view('user.register');
    }

    public function login()
    {
        return view('user.login');
    }

    public function registerForm(Request $request)
    {
        $input = $request->all();
        $rules = [
            'mobile' => 'required|unique:users|max:15',
        ];
        $validator = Validator::make($input, $rules);

        if ($validator->fails()) {
            Session::flash('error', 'Mobile number is already exists.');
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $firstCharacter = substr($request->get('mobile'), 0, 1);
        if($firstCharacter != 6 && $firstCharacter != 7 && $firstCharacter != 8 && $firstCharacter != 9){
            Session::flash('error', 'Mobile number is not valid, Please enter valid mobile number.');
            return redirect()->back()->withErrors($validator)->withInput();
        }

        if ($request->get('referral_code')) {
            $checkCount = User::where('refer_code', $request->get('referral_code'))->count();
            if ($checkCount == 0) {
                Session::flash('error', 'Please enter valid referral code.');
                return redirect()->back()->withInput($request->all());
            }
        }

        $user = new User();
        $user->password = Hash::make($request->get('password'));
        $user->name = $request->get('fullname');
        $user->mobile = $request->get('mobile');
        $user->referral_code = $request->get('referral_code');
        $user->refer_code = $this->generateRandomString(6);
        //$user->verification_code = $this->generateRandomString(6);
        //$user->verification_code = 123456;
        $user->role = 'user';
        $user->status = '1';

        // remove otp section
        $user->is_mobile_verify = 1;
        $user->verification_code = null;

        if ($user->save()) {
            //return redirect('mobile-otp');

            if(isset($user->referral_code)){
                $referralUserData = User::where('refer_code', $user->referral_code)->get()->first();
                $dateTime = date('Y-m-d H:i:s');
                $wallet = new UserWallet;
                $wallet->user_id = $referralUserData->id;
                $wallet->referral_user_id = $user->id;
                $wallet->amount =  Config::get('constants.REFERRAL_REWARD_AMOUNT');
                $wallet->date =  $dateTime;
                $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.REFERRAL_REWARD');
                $wallet->status = '2';
                $wallet->save();
            }
            Session::flash('success', 'Registerd successfully, you can login now.');
            return redirect('login');
        } else {
            return redirect()->back()->with('error', 'Not able to register right now, please try again later.');
        }
    }

    /** OTP verify */
    public function mobileOtp(Request $request)
    {
        if ($request->isMethod('post')) {
            $userData = User::where('verification_code', $request->get('otp'))->get()->first();
            if (isset($userData->id)) {
                
                $userData->is_mobile_verify = 1;
                $userData->verification_code = null;
                if ($userData->save()) {

                    if(isset($userData->referral_code)){
                        $referralUserData = User::where('refer_code', $userData->referral_code)->get()->first();
                        $dateTime = date('Y-m-d H:i:s');
                        $wallet = new UserWallet;
                        $wallet->user_id = $referralUserData->id;
                        $wallet->referral_user_id = $userData->id;
                        $wallet->amount =  Config::get('constants.REFERRAL_REWARD_AMOUNT');
                        $wallet->date =  $dateTime;
                        $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.REFERRAL_REWARD');
                        $wallet->save();
                    }
                   
                    Session::flash('success', 'Registerd successfully, you can login now.');

                    return redirect('login');
                }
            } else {
                Session::flash('error', 'Invalid OTP, Please try again.');

                return redirect()->back()->withInput($request->all());
            }
        }

        return view('user.mobile_otp');
    }

    public function generateRandomString($length = 10)
    {
        $characters = '0123456789ABCD5FD3HEFGHI76JKLMNOPQR345345STUV6HFXNK75FGJHGTL5OI4FKWQLK4RGDVJ3QEDLK5YUFGFBJKW4KLJ5WETGUIWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; ++$i) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }

        return $randomString;
    }

    public function loginForm(Request $request)
    {
        $credentials = request()->only(['mobile', 'password']);
        if (Auth::attempt($credentials)) {
            if (Auth::user()->role == 'admin') {
                Auth::logout();
                Session::flash('success', 'Invlaid mobile number or password.');

                return redirect('login');
            } elseif (Auth::user()->status == 0) {
                Auth::logout();
                Session::flash('success', 'Your account has been blocked.');
                return redirect('login');
            } else {
                return redirect('home');
            }
        } else {
            Session::flash('error', 'Invlaid mobile number or password.');

            return redirect('login');
        }
    }

    public function walletHistory(Request $request)
    {
        $userData = Auth::user();
        $userId = $userData->id;
        $walletData = UserWallet::with(['payment','referralUser'])
            ->where('user_id', $userId)
            ->orderBy('id','DESC')
            ->paginate(Config::get('constants.PAGING_LIMIT'));
        $const = Config::get('constants');
        $walletAmount = CommonHelper::getUserWalletAmount($userId);
        return view('user.wallet', compact('walletData','const','walletAmount'));
    }

    public function profile(Request $request)
    {
        $userData = Auth::user();
        if ($request->isMethod('post')) {
            $user = User::find($userData->id);
            $user->name = $request->get('name');
            $user->bank_name = $request->get('bank_name');
            $user->account_holder_name = $request->get('account_holder_name');
            $user->ifsc_code = $request->get('ifsc_code');
            $user->account_number = $request->get('account_number');
            if ($user->save()) {
                Session::flash('success', 'Profile has been updated successfully.');

                return redirect('profile');
            } else {
                Session::flash('error', 'Not able to update your profile please try again.');

                return redirect('profile');
            }
        }

        return view('user.front_profile', compact('userData'));
    }

    public function changePassword(Request $request)
    {
        if ($request->isMethod('post')) {
            $userData = Auth::user();
            $user = User::find($userData->id);
            $oldPassword = $request->get('old_password');
            if (Hash::check($oldPassword, $user->password)) {
                $user->password = Hash::make($request->get('password'));
                if ($user->save()) {
                    Session::flash('success', 'Your password has been updated successfully.');
                } else {
                    Session::flash('error', 'Not able to update your password please try again.');
                }
            } else {
                Session::flash('error', 'Your old password is not match with over record.');
            }

            return redirect('change-password');
        }

        return view('user.change_password');
    }

    public function requestAmount(Request $request)
    {
        $minRequestAmount = Config::get('constants.MINIMUM_REQUEST_AMOUNT');
        $userData = Auth::user();
        $isDisableRequest = false;
        $userWalletAmount = CommonHelper::getUserWalletAmount($userData->id);
        $minWalletAmount = Config::get('constants.MIN_WALLET_AMOUNT');
        if(trim($userData->bank_name) != '' && trim($userData->account_holder_name) != '' && trim($userData->ifsc_code) != '' && trim($userData->account_number) != ''){
           
            if ($request->isMethod('post')) {
                $input = $request->all();
                $rules = [
                    'amount' => 'required|max:10|min:1',
                ];
                $validator = Validator::make($input, $rules);

                if ($validator->fails()) {
                    Session::flash('error', 'Please enter valid amount.');
                    return redirect()->back()->withErrors($validator)->withInput();
                }

                if($input['amount'] < $minRequestAmount){
                    Session::flash('error', 'Minimum amount should be greater than of RS '.$minRequestAmount.'.');
                    return redirect('request-amount');
                } else {
                if($input['amount'] > ($userWalletAmount - $minWalletAmount)){
                    $am = $userWalletAmount - $minWalletAmount;
                    Session::flash('error', 'Amount should be less then of rs '.$am.'.');
                    return redirect('request-amount');
                } else {
                        $dateTime = date('Y-m-d H:i:s');
                        $wallet = new UserWallet;
                        $wallet->user_id = $userData->id;
                        $wallet->amount = $input['amount'];
                        $wallet->date =  $dateTime;
                        $wallet->payment_type = Config::get('constants.USER_WALLET_STATUS.WITHDRAW_REQUEST');
                        if ($wallet->save()) {
                            Session::flash('success', 'Your amount withdrawal request has been successfully sent waiting for approval.');
                            return redirect('request-amount');
                        } else {
                            Session::flash('error', 'Not able to send request. please try again.');
                            return redirect('request-amount');
                        }
                    }
                }
                
            }
        } else {
            $isDisableRequest = true;    
        }
        
        return view('user.request_amount',compact('userWalletAmount','minWalletAmount','isDisableRequest','minRequestAmount'));
    }

    public function logout()
    {
        Auth::logout();

        return redirect('home');
    }

    public function checkMobileNumber(Request $request)
    {
        $mobileNumber = $request->get('mobile');
        $checkCount = User::where('mobile', $mobileNumber)->count();
        if ($checkCount > 0) {
            return 0;
        } else {
            return 1;
        }
    }

    public function forgotPassword(Request $request){
        if($request->isMethod('post')){
            $mobileNumber = $request->get('mobile');
            $userData = User::where(['mobile'=>$mobileNumber,'role'=>'user'])->get()->first();
            if (isset($userData->id)) {
                $user = User::find($userData->id);
                //$user->password = Hash::make($request->get('password'));
                //$user->verification_code = $this->generateRandomString(6);
                $user->verification_code = 654321;
                if ($user->save()) {
                    Session::flash('success', 'OTP has been successfully send to your mobile number.');
                    return redirect('reset-password');
                } else {
                    return redirect()->back()->with('error', 'Not able to send OTP, please try again later.');
                }
            } else {
                Session::flash('error', 'Please enter valid mobile number.');
                return redirect('forgot-password');
            }
        }
        return view('user.forgot_password');
        
    }

    public function resetPassword(Request $request){
        if($request->isMethod('post')){
            $userData = User::where('verification_code', $request->get('otp'))->get()->first();
            if(isset($userData->id)){
                $user = User::find($userData->id);
                $user->password = Hash::make($request->get('password'));
                $user->verification_code = NULL;
                if ($user->save()) {
                    Session::flash('success', 'Your password has been changed successfully, please login with new password.');
                    return redirect('login');
                } else {
                    return redirect()->back()->with('error', 'Not able to verify OTP, please try again later.');
                }
            } else {
                Session::flash('error', 'Please enter valid OTP.');
                return redirect('reset-password');
            }

        }
        return view('user.reset_password');
    }

    public function payFirstEmi(){
        $msg = "Not Found";
        $today = date('Y-m-d');
        $payments = Payment::where(['status'=>'1','first_payment_status'=>'0','first_payment_date'=>$today])->get();
        //dd($payments);
        foreach($payments as $k => $data){
            $paymentData = Payment::find($data->id);
            $paymentData->first_payment_status = 1;
            if ($paymentData->save()) {
                $msg = "Success";
                $dateTime = date('Y-m-d H:i:s');
                $wallet = new UserWallet;
                $wallet->user_id = $paymentData->user_id;
                $wallet->payment_id = $paymentData->id;
                $wallet->amount =  Config::get('constants.FIRST_EMI_PAYMENT');
                $wallet->date =  $dateTime;
                $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.FIRST_EMI_APPROVED');
                $wallet->save();
            }
        }
        echo $msg;
    }

    public function paySecondEmi(){
        $msg = "Not Found";
        $today = date('Y-m-d');
        $payments = Payment::where(['status'=>'1','second_payment_status'=>'0','second_payment_date'=>$today])->get();
        foreach($payments as $k => $data){
            $paymentData = Payment::find($data->id);
            $paymentData->second_payment_status = 1;
            if ($paymentData->save()) {
                $msg = "Success";
                $dateTime = date('Y-m-d H:i:s');
                $wallet = new UserWallet;
                $wallet->user_id = $paymentData->user_id;
                $wallet->payment_id = $paymentData->id;
                $wallet->amount =  Config::get('constants.SECOND_EMI_PAYMENT');
                $wallet->date =  $dateTime;
                $wallet->payment_type =  Config::get('constants.USER_WALLET_STATUS.SECOND_EMI_APPROVED');
                $wallet->save();
            }
        }
        echo $msg;
        
    }

    /**
     * Method: addAmount
     * Des: here user will add add money request in wallet
     */
    public function addAmount(Request $request)
    {
        $minAddWalletAmount = Config::get('constants.MINIMUM_ADD_WALLET_AMOUNT');
        $userData = Auth::user();
        $isDisableRequest = false;
        $userWalletAmount = CommonHelper::getUserWalletAmount($userData->id);
        $minWalletAmount = Config::get('constants.MIN_WALLET_AMOUNT');
           
            if ($request->isMethod('post')) {
                $input = $request->all();
                $rules = [
                    'amount' => 'required|max:10|min:1',
                ];
                $validator = Validator::make($input, $rules);

                if ($validator->fails()) {
                    Session::flash('error', 'Please enter valid amount.');
                    return redirect()->back()->withErrors($validator)->withInput();
                }

                if($input['amount'] < $minAddWalletAmount){
                    Session::flash('error', 'Minimum amount should be greater than of RS '.$minAddWalletAmount.'.');
                    return redirect('add-amount');
                } else {
                    $dateTime = date('Y-m-d H:i:s');
                    $wallet = new UserWallet;
                    $wallet->user_id = $userData->id;
                    $wallet->amount = $input['amount'];
                    $wallet->date =  $dateTime;

                    if ($request->hasFile('payment_schreenshot')) {
                        $extension = $input['payment_schreenshot']->getClientOriginalExtension();
                        $fileName = time() . '-payment-image.' . $extension;
                        if ($input['payment_schreenshot']->move('public/uploads/payment/', $fileName)) {
                            $wallet->payment_image = $fileName;
                        }
                    }

                    $wallet->payment_type = Config::get('constants.USER_WALLET_STATUS.PENDING_AMOUNT_ADD_REQUEST_IN_WALLET');
                    if ($wallet->save()) {
                        Session::flash('success', 'Your amount add request has been successfully sent waiting for approval.');
                        return redirect('add-amount');
                    } else {
                        Session::flash('error', 'Not able to send request. please try again.');
                        return redirect('add-amount');
                    }
                }
                
            }
        
        
        return view('user.add_amount',compact('userWalletAmount','minWalletAmount','minAddWalletAmount'));
    }

}
