<?php

use App\Exports\UsersExport;
use App\Http\Controllers\Admin\AdminController;
//Namespace Auth
use App\Http\Controllers\Admin\PaymentController;
//Namespace Admin
use App\Http\Controllers\Auth\LoginController;
//Namespace User
use App\Http\Controllers\HomeController;
use App\Http\Controllers\PageController;
use App\Http\Controllers\User\ProfileController;
use App\Http\Controllers\User\UserController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\UserController as AdminUserController;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/home', [HomeController::class, 'index'])->name('home');
Route::get('/', [HomeController::class, 'index'])->name('home');

Route::group(['namespace' => 'Admin', 'middleware' => 'auth', 'prefix' => 'admin'], function () {
    Route::get('/', [AdminController::class, 'index'])->name('admin')->middleware(['can:admin']);

    //Route Rescource
    Route::resource('/user', 'UserController')->middleware(['can:admin']);

    //Route View
    Route::view('/404-page', 'admin.404-page')->name('404-page');
    Route::view('/blank-page', 'admin.blank-page')->name('blank-page');

    Route::post('/logout', function () {
        return redirect()->to('admin/login')->with(Auth::logout());
    })->name('logout-admin');
});

// if admin login
Route::group(['namespace' => 'User', 'middleware' => ['auth', 'can:admin'], 'prefix' => 'user'], function () {
    Route::get('/', [UserController::class, 'index'])->name('user');
    Route::get('/profile', [ProfileController::class, 'index'])->name('admin.profile');
    Route::post('/setting', [ProfileController::class, 'settingUpdate'])->name('setting.update');
    Route::patch('/profile/update/{user}', [ProfileController::class, 'update'])->name('profile.update');

    Route::get('/payment-list', [PaymentController::class, 'index'])->name('payment-list');
    Route::get('/payment-view/{id}', [PaymentController::class, 'show'])->name('payment-view');
    Route::get('/sponsor-details', [PaymentController::class, 'sponsorDetail'])->name('sponsor-details');
    Route::get('/emi-details', [PaymentController::class, 'emiDetail'])->name('emi-details');
    Route::get('/backup-data', [PaymentController::class, 'emiDetail2'])->name('emi-details2');
    Route::get('/update-payment-status/{id}/{column}/{value}', [PaymentController::class, 'updatePaymentStatus'])->name('update-payment-status');
    Route::get('/user-list',[AdminUserController::class,'index'])->name('user-list');
    Route::get('/user-wallet/{userid?}',[AdminUserController::class,'wallet'])->name('user-wallet');
    Route::get('/update-wallet-status/{id}/{column}/{value}/{walletAmount?}', [AdminUserController::class, 'updateWalletStatus'])->name('update-wallet-status');
    Route::get('/wallet-detail/{id}/', [AdminUserController::class, 'walletDetail'])->name('wallet-details');
    Route::get('/user-add-money/{userid?}',[AdminUserController::class,'addMoneyInWallet'])->name('user-add-money');


});

// if admin not login
Route::group(['namespace' => 'Auth', 'middleware' => 'guest', 'prefix' => 'admin'], function () {
    Route::view('/login', 'auth.login')->name('login');
    Route::post('/login', [LoginController::class, 'authenticate'])->name('login.post');
    Route::view('/register', 'auth.register')->name('register');
    Route::view('/forgot-password', 'auth.forgot-password')->name('forgot-password');
});

// front
Route::group(['middleware' => ['auth.front', 'can:user']], function () {
    Route::get('/purchase-ticket', [UserController::class, 'purchaseTicket'])->name('purchase-ticket');
    Route::post('/purchase-ticket-form', [UserController::class, 'purchaseTicketForm'])->name('purchase-ticket-form');
    Route::get('/purchase-pin', [UserController::class, 'purchasePin'])->name('purchase-pin');
    Route::get('/purchase-pin-by-wallet', [UserController::class, 'purchasePinByWallet'])->name('purchase-pin-by-wallet');
    Route::get('/thank-you/{pId}', [UserController::class, 'thankYou'])->name('thank-you');
    Route::get('/wallet-history', [UserController::class, 'walletHistory'])->name('wallet-history');
    Route::match(['get', 'post'], '/profile', [UserController::class, 'profile'])->name('profile');
    Route::match(['get', 'post'], '/change-password', [UserController::class, 'changePassword'])->name('change-password');
    Route::match(['get', 'post'], '/request-amount', [UserController::class, 'requestAmount'])->name('request-amount');

    Route::match(['get', 'post'], '/add-amount', [UserController::class, 'addAmount'])->name('add-amount');
    Route::get('/logout', [UserController::class, 'logout'])->name('logout');
});
// front end auth route

// Route::get('/test-data', function () {
//     return Excel::download(new UsersExport(), 'payments.xlsx');
//     exit;
// });

Route::group(['namespace' => 'User'], function () {
    Route::get('/backup-data', [PaymentController::class, 'emiDetail2'])->name('emi-details2');
});

// front auth not required
Route::get('/register', [UserController::class, 'register'])->name('register-front-user');
Route::post('/register', [UserController::class, 'registerForm'])->name('register-front-user-form');
Route::get('/login', [UserController::class, 'login'])->name('login-front-user');
Route::post('/login', [UserController::class, 'loginForm'])->name('login-front-user-form');
Route::get('/about-us', [PageController::class, 'aboutUs'])->name('about-us');
Route::match(['get', 'post'], '/mobile-otp', [UserController::class, 'mobileOtp'])->name('mobile-otp');
Route::match(['get', 'post'], '/forgot-password', [UserController::class, 'forgotPassword'])->name('forgot-password');
Route::match(['get', 'post'], '/reset-password', [UserController::class, 'resetPassword'])->name('reset-password');

Route::post('/mobilenumber-check', [UserController::class, 'checkMobileNumber'])->name('check-number');

// CRON reset temp payments
Route::get('/reset-temp-payments', [UserController::class, 'resetPayments'])->name('reset-temp-payments');

// CRON pay first EMI
Route::get('/pay-first-emi', [UserController::class, 'payFirstEmi'])->name('pay-first-emi');

// CRON pay second EMI
Route::get('/pay-second-emi', [UserController::class, 'paySecondEmi'])->name('pay-second-emi');